pub enum EnableBackground {
Accumulate,
New(Option<Rect>),
}Expand description
enable-background property.
SVG1.1: https://www.w3.org/TR/SVG11/filters.html#EnableBackgroundProperty
This is deprecated in SVG2. We just have a parser for it to avoid setting elements in error if they have this property. Librsvg does not use the value of this property.
Variants