#[repr(C)]pub enum ImageRendering {
Auto = 0,
Smooth = 1,
OptimizeQuality = 2,
HighQuality = 3,
CrispEdges = 4,
OptimizeSpeed = 5,
Pixelated = 6,
}Expand description
image-rendering property.
CSS Images Module Level 3: https://www.w3.org/TR/css-images-3/#the-image-rendering
Note that this property previously accepted the values optimizeSpeed and optimizeQuality. These are now deprecated; a user agent must accept them as valid values but must treat them as having the same behavior as crisp-edges and smooth respectively.
Variants
Auto = 0
Smooth = 1
OptimizeQuality = 2
HighQuality = 3
CrispEdges = 4
OptimizeSpeed = 5
Pixelated = 6