#[repr(C)]pub enum XmlSpace {
Default = 0,
Preserve = 1,
}Expand description
xml:space attribute.
XML1.0: https://www.w3.org/TR/xml/#sec-white-space
Similar to XmlLang, this is a hack in librsvg. The xml:space attribute is
supposed to be applied to all the children of the element in which it appears, so
it works more or less the same as CSS property inheritance. Librsvg reuses the
machinery for CSS property inheritance to propagate down the value of xml:space
to an element’s children.
Variants